%% This script analyses the 8 repetitions / 5 phantom dataset with 01340

%% load the data
a = dir('mat/arms/*.mat'); 
% print a resume
for ii = 1:numel(a)
    load(fullfile(a(ii).folder, a(ii).name)); 
    arm(ii).RAW = RAW; 
    arm(ii).HBC = HBC; 
    arm(ii).name = a(ii).name(1:end-4); 
    
    arm(ii).HBC.THC = HBC.absHHb + HBC.absO2Hb; 
    arm(ii).RAW.CTS = 2^16*exp(-RAW.OD); 
end

%% extract the repetitions info from the files
SKIPNEXT = 0;
for ii = 1:numel(a)
    evs = arm(ii).HBC.events;
    PLNMS = {{'pl1', 'A'}, 'pl2', 'pl3', 'pl4', 'pl5', 'pl6', 'pl7', 'pl8'};
    for jj = 1:numel(PLNMS)
        if SKIPNEXT, SKIPNEXT=0; continue; end
        tmp_ix = find(ismember(evs.names, PLNMS{jj})); 
            % index in rep(ii).HBC.events of the jj-th phantom
        ixs{ii,jj} = sort(evs.onsets{tmp_ix}([1,2])); 
            % indices of the data of the jj-th panthom in the ii-th rep are
            % ixs{ii, jj}(1):ixs{ii, jj}(2)
        if numel(evs.onsets{tmp_ix})==4
            % I made some confusion naming the placemnets///
            SKIPNEXT = 1; % SKIPS NEXT CYCLE
            ixs{ii,jj+1} = sort(evs.onsets{tmp_ix}([3,4])); 
        end
    end
end

for ii = 1:size(ixs,1)
    HBC = arm(ii).HBC; 
    RAW = arm(ii).RAW; 
    for jj = 1:size(ixs,2)
    % *compute mean and std of the TSI and OD for all arm
    % placememt/replacement
        ts{ii,jj} = HBC.TSI(ixs{ii,jj}(1):ixs{ii,jj}(2));           % time series
        ATSI(ii,jj) = mean(HBC.TSI(ixs{ii,jj}(1):ixs{ii,jj}(2))); % average 
        STSI(ii,jj) = std(HBC.TSI(ixs{ii,jj}(1):ixs{ii,jj}(2)),0,1); % STD
        ATHC(ii,jj) = mean(HBC.THC(ixs{ii,jj}(1):ixs{ii,jj}(2))); % average 
        STHC(ii,jj) = std(HBC.THC(ixs{ii,jj}(1):ixs{ii,jj}(2)),0,1); % STD
        DTSI(ii,jj) = diff(ixs{ii,jj})+1; % length in no. samples
        for kk = 1:6
            AOD(ii,jj, kk) = mean(arm(ii).RAW.OD(ixs{ii,jj}(1):ixs{ii,jj}(2), kk)); % average 
            SOD(ii,jj, kk) = std(arm(ii).RAW.OD(ixs{ii,jj}(1):ixs{ii,jj}(2), kk),0,1); % STD
            DOD(ii,jj) = diff(ixs{ii,jj})+1; % length in no. samples      
        end
    end

end

%% REMOVE SOME OUTLIERS (big movements during the single acquisition): 
ATSI(1,1) = NaN; ATHC(1,1) = NaN; STSI(1,1) = NaN; ts{1,1} = NaN; STHC(1,1) = NaN;
ATSI(7,7) = NaN; ATHC(7,7) = NaN; STSI(7,7) = NaN; ts{7,7} = NaN; STHC(7,7) = NaN;
ATSI(3,2) = NaN; ATHC(3,2) = NaN; STSI(3,2) = NaN; ts{3,2} = NaN; STHC(3,2) = NaN;
ATSI(10,1) = NaN; ATHC(10,1) = NaN; STSI(10,1) = NaN; ts{10,1} = NaN; STHC(10,1) = NaN;



%% plots +0.2*(rand(size(ATSI(ii,5:8)))-0.5)
% /// TSI repetition vs Device
figure; 
lgnd = {}; jcm = cool(size(ATSI,1)); 
subplot(2,1,1); 
boxplot(ATSI','Colors','k'); hold on; 
for ii = 1:size(ATSI,1)
    plo{ii} = errorbar(ii*ones(size(ATSI(ii,1:4)))+0.3*(rand(size(ATSI(ii,1:4)))-0.5), ATSI(ii,1:4), STSI(ii,1:4), 'ks','MarkerFaceColor','k',  'markersize', 9); %'color', jcm(ii,:),
    lgnd = [lgnd ['id*' arm(ii).name(end-1:end)]]; 
    if ii>1; set(plo{ii}, 'HandleVisibility', 'off'); end
end
for ii = 1:size(ATSI,1)
    plo{ii} = errorbar(ii*ones(size(ATSI(ii,5:8)))+0.3*(rand(size(ATSI(ii,5:8)))-0.5), ATSI(ii,5:8), STSI(ii,5:8), 'ko','MarkerFaceColor','k', 'markersize', 9);%, ...
        %'color', plo{ii}.Color, 'markerfacecolor', plo{ii}.Color*.8, 'markerFaceAlpha', .7); % I was trying to be fancy
    if ii>1; set(plo{ii}, 'HandleVisibility', 'off'); end
end
AA=gca;
AA.XGrid = 'on' ;
set(gca, 'xtick', 1:numel(lgnd)); set(gca, 'xticklabel', lgnd)
xlabel('device name'); ylabel('TSI (%)'); 
% legend('first 4', 'second 4','location','best'); 

subplot(2,1,2); 
boxplot(ATHC','Colors','k'); hold on; 
for ii = 1:size(ATSI,1)
    plo{ii} = errorbar(ii*ones(size(ATHC(ii,1:4)))+0.3*(rand(size(ATHC(ii,1:4)))-0.5), ATHC(ii,1:4), STHC(ii,1:4), 'ks','MarkerFaceColor','k',  'markersize', 9); 
    lgnd = [lgnd ['id*' arm(ii).name(end-1:end)]]; 
    if ii>1; set(plo{ii}, 'HandleVisibility', 'off'); end
end
for ii = 1:size(ATSI,1)
    plo{ii} = errorbar(ii*ones(size(ATHC(ii,5:8)))+0.4*(rand(size(ATHC(ii,5:8)))-0.5), ATHC(ii,5:8), STHC(ii,5:8), 'ko','MarkerFaceColor','k', 'markersize', 9);%, ...
        %'color', plo{ii}.Color, 'markerfacecolor', plo{ii}.Color*.8, 'markerFaceAlpha', .7); % I was trying to be fancy
    if ii>1; set(plo{ii}, 'HandleVisibility', 'off'); end
end
set(gca, 'xtick', 1:numel(lgnd)); set(gca, 'xticklabel', lgnd)
xlabel('device name'); ylabel('THC (\muM)'); 
% legend('first 4', 'second 4','location','best'); 
AA=gca;
AA.XGrid = 'on' ;


















